/**
 * Gestion JS de WPshop.
 *
 * @since   2.0.0
 * @version 2.0.0
 */
window.eoxiaJS.wpshop = {};
window.eoxiaJS.wpshopFrontend = {};

/**
 * La méthode "init" est appelé automatiquement par la lib JS de Eo-Framework
 *
 * @since   2.0.0
 * @version 2.0.0
 */
window.eoxiaJS.wpshop.init = function() {
	window.eoxiaJS.wpshop.event();

	if ( jQuery( '.wps-sync' ).length ) {
		jQuery( '.wps-sync' ).each( function() {
			var data = {
				action: 'check_sync_status',
				wp_id: jQuery( this ).find( '.button-synchro' ).data( 'wp-id' ),
				type: jQuery( this ).find( '.button-synchro' ).data( 'type' )
			};

			window.eoxiaJS.loader.display( jQuery( this ) );

			var _this = jQuery( this );

			// @todo: Handle fatal error or no response.
			jQuery.post( ajaxurl, data, function( response ) {
				window.eoxiaJS.loader.remove(_this);
				_this.replaceWith( response.data.view );

				if ( response.data.status && response.data.status.status_code == '0x1' ) {
					jQuery( '.table-row[data-id="' + response.data.id + '"] .reference-id li:last' ).remove();
				}
			} )
				.fail( function() {
					window.eoxiaJS.loader.remove(_this);
					_this.find( ".statut" ).attr( 'aria-label', '500 (Internal Server Error)' );
					_this.find( ".statut" ).addClass( 'statut-red' );
				} );
		} );
	}

	var data = {
		action: 'check_erp_statut',
		_wpnonce: scriptParams.check_erp_statut_nonce
	};

	jQuery.post( ajaxurl, data, function( response ) {
		if ( ! response.data.statut && response.data.view ) {
			jQuery( 'body' ).append( response.data.view );
		}
	} );
};

/**
 * Les évènements du core.
 *
 * @since   2.3.0
 * @version 2.3.0
 */
window.eoxiaJS.wpshop.event = function() {
	jQuery( document ).on( 'click', '.wpeo-notification .notification-close', window.eoxiaJS.wpshop.close );
};

/**
 * Fait disparaitre la popup notification.
 *
 * @since   2.3.0
 * @version 2.3.0
 *
 * @param {ClickEvent}  event [displayBlockStock].
 */
window.eoxiaJS.wpshop.close = function( event) {
	jQuery( this ).closest( '.wpeo-notification' ).fadeOut();
};

/**
 * Gestion JS du panier.
 *
 * @since   2.0.0
 * @version 2.0.0
 */
window.eoxiaJS.wpshopFrontend.cart = {};

/**
 * La méthode "init" est appelé automatiquement par la lib JS de Eo-Framework
 *
 * @since   2.0.0
 * @version 2.0.0
 */
window.eoxiaJS.wpshopFrontend.cart.init = function() {
	window.eoxiaJS.wpshopFrontend.cart.event();
};

window.eoxiaJS.wpshopFrontend.cart.event = function() {
	jQuery( document ).on( 'click', '.wps-cart .wps-product-quantity .wps-quantity-minus', window.eoxiaJS.wpshopFrontend.cart.updateQuantity );
	jQuery( document ).on( 'click', '.wps-cart .wps-product-quantity .wps-quantity-plus', window.eoxiaJS.wpshopFrontend.cart.updateQuantity );
};

/**
 * Met à jour la quantité d'un produit.
 *
 * @since   2.0.0
 * @version 2.0.0
 *
 * @param {ClickEvent} event [updateQuantity].
 */
window.eoxiaJS.wpshopFrontend.cart.updateQuantity = function( event ) {
	var qty = parseInt( jQuery( this ).closest( '.wps-product-quantity' ).find( 'input[type="hidden"]' ).val() );

	if ( jQuery( this ).hasClass( 'wps-quantity-minus' ) ) {
		if ( qty > 1 ) {
			qty--;
		}
	}

	if ( jQuery( this ).hasClass( 'wps-quantity-plus' ) ) {
		qty++;
	}

	jQuery( this ).closest( '.wps-product-quantity' ).find( '.qty' ).text( qty );
	jQuery( this ).closest( '.wps-product-quantity' ).find( 'input[type="hidden"]' ).val( qty );
	jQuery( '.wps-cart .update-cart' ).click();

	window.eoxiaJS.loader.display( jQuery( '.wps-cart-resume' ) );
};

/**
 * Le callback en cas de réussite à la requête Ajax "add_to_cart".
 * Ajoute un produit au panier.
 *
 * @since   2.0.0
 * @version 2.0.0
 *
 * @param {HTMLDivElement} triggeredElement L'élement HTML déclenchant la requête Ajax.
 * @param {Object}         response         Les données renvoyées par la requête Ajax.
 */
window.eoxiaJS.wpshopFrontend.cart.addedToCart = function ( triggeredElement, response ) {
	if ( response.data.added ) {
		var tmp = jQuery( response.data.view );
		jQuery( 'body' ).append( tmp );

		tmp.timeout = setTimeout( function() {
			tmp.remove();
		}, 5000 );
	}

	if ( response.data.qty ) {
		jQuery( '.cart-button .qty' ).html( '(<span class="qty-value">' + response.data.qty + '</span>)' );
	}
};

/**
 * Le callback en cas de réussite à la requête Ajax "update_cart".
 * Met à jour le panier.
 *
 * @since   2.0.0
 * @version 2.0.0
 *
 * @param {HTMLDivElement} triggeredElement L'élement HTML déclenchant la requête Ajax.
 * @param {Object}         response         Les données renvoyées par la requête Ajax.
 */
window.eoxiaJS.wpshopFrontend.cart.updatedCart = function ( triggeredElement, response ) {
	jQuery( '.wps-cart' ).replaceWith( response.data.view );

	if ( response.data.qty == 0 ) {
		jQuery( '.cart-button .qty' ).html( '<span class="qty-value"></span>' );

	} else {
		jQuery( '.cart-button .qty' ).html( '(<span class="qty-value">' + response.data.qty + '</span>)' );
	}
};

/**
 * Le callback en cas de réussite à la requête Ajax "delete_product_form_cart".
 * Supprime un produit du panier.
 *
 * @since   2.0.0
 * @version 2.0.0
 *
 * @param {HTMLDivElement} triggeredElement L'élement HTML déclenchant la requête Ajax.
 * @param {Object}         response         Les données renvoyées par la requête Ajax.
 */
window.eoxiaJS.wpshopFrontend.cart.deletedProdutFromCart = function ( triggeredElement, response ) {
	jQuery( '.wps-cart' ).replaceWith( response.data.view );

	if ( response.data.qty == 0 ) {
		jQuery( '.cart-button .qty' ).html( '<span class="qty-value"></span>' );

	} else {
		jQuery( '.cart-button .qty' ).html( '(<span class="qty-value">' + response.data.qty + '</span>)' );
	}
};

/**
 * Gestion JS de la méthode de paiement Stripe.
 *
 * @since   2.0.0
 * @version 2.0.0
 */
window.eoxiaJS.wpshopFrontend.stripe = {};

/**
 * La méthode "init" est appelé automatiquement par la lib JS de Eo-Framework.
 *
 * @since   2.0.0
 * @version 2.0.0
 */
window.eoxiaJS.wpshopFrontend.stripe.init = function() {};

/**
 * Le callback en cas de réussite à la requête Ajax "redirect_to_payment".
 * Redirection sur la page de paiement Stripe.
 *
 * @since   2.0.0
 * @version 2.0.0
 *
 * @param {HTMLDivElement} triggeredElement L'élement HTML déclenchant la requête Ajax.
 * @param {Object}         response         Les données renvoyées par la requête Ajax.
 */
window.eoxiaJS.wpshopFrontend.stripe.redirectToPayment = function(triggeredElement, response) {
	var stripe = Stripe(
	  stripe_key,
	  {
	    betas: ['checkout_beta_4'],
	  }
	);

	stripe.redirectToCheckout({
 		sessionId: response.data.id
	}).then(function (result) {
	  console.log(result);
	});
};

/**
 * Gestion JS du tunnel de vente.
 *
 * @since   2.0.0
 * @version 2.0.0
 */
window.eoxiaJS.wpshopFrontend.checkout = {};

/**
 * La méthode "init" est appelé automatiquement par la lib JS de Eo-Framework.
 *
 * @since   2.0.0
 * @version 2.0.0
 */
window.eoxiaJS.wpshopFrontend.checkout.init = function() {
	window.eoxiaJS.wpshopFrontend.checkout.event();
};

/**
 * Les évènements du tunnel de vente.
 *
 * @since   2.0.0
 * @version 2.0.0
 */
window.eoxiaJS.wpshopFrontend.checkout.event = function() {
	jQuery( '.checkout-login .checkout-login-toggle' ).click( function() {
		jQuery( '.checkout-login .content-login' ).slideToggle();
	} );

	jQuery( document ).on( 'change', '.wps-checkout .wps-payment-list li.wps-payment input', window.eoxiaJS.wpshopFrontend.checkout.makeActive );
};

/**
 * Active les paiements dans le tunnel de vente.
 *
 * @since   2.0.0
 * @version 2.0.0
 *
 * @param {ClickEvent} event [makeActive].
 */
window.eoxiaJS.wpshopFrontend.checkout.makeActive = function( event ) {
	jQuery( '.wps-checkout .wps-payment-list li.wps-payment.checked' ).removeClass( 'checked' );
	jQuery( this ).closest( 'li.wps-payment' ).addClass( 'checked' );
};


window.eoxiaJS.wpshopFrontend.checkout.loadedEditBillingAddress = function( triggeredElement, response ) {
	jQuery( '.shipping-contact' ).html( response.data.view );
};

/**
 * Le callback en cas de réussite à la requête Ajax "".
 * Supprime un produit du panier.
 *
 * @since   2.0.0
 * @version 2.0.0
 *
 * @param {HTMLDivElement} triggeredElement L'élement HTML déclenchant la requête Ajax.
 * @param {Object}         response         Les données renvoyées par la requête Ajax.
 */
window.eoxiaJS.wpshopFrontend.checkout.checkoutErrors = function( triggeredElement, response ) {
	if ( 0 === jQuery( 'form.wps-checkout-step-1 ul.error.notice' ).length ) {
		jQuery( '.wps-checkout .wps-checkout-step-1' ).prepend( response.data.template );
	} else {
		jQuery( '.wps-checkout .wps-checkout-step-1 ul.error.notice' ).replaceWith( response.data.template );
	}

	for ( var key in response.data.errors.error_data ) {
		jQuery( '.wps-checkout .' + response.data.errors.error_data[ key ].input_class ).addClass( 'form-element-error' );
	}
};

/**
 * Le callback en cas de réussite à la requête Ajax "create_third_party".
 * Crée un third party et fait une redirection.
 *
 * @since   2.0.0
 * @version 2.0.0
 *
 * @param {HTMLDivElement} triggeredElement L'élement HTML déclenchant la requête Ajax.
 * @param {Object}         response         Les données renvoyées par la requête Ajax.
 */
window.eoxiaJS.wpshopFrontend.checkout.createdThirdSuccess = function( triggeredElement, response ) {
	document.location.href = response.data.redirect_url;
};

/**
 * Le callback en cas de réussite à la requête Ajax "redirect_to_payment".
 * Redirige sur le site du paiement.
 *
 * @since   2.0.0
 * @version 2.0.0
 *
 * @param {HTMLDivElement} triggeredElement L'élement HTML déclenchant la requête Ajax.
 * @param {Object}         response         Les données renvoyées par la requête Ajax.
 */
window.eoxiaJS.wpshopFrontend.checkout.redirectToPayment = function( triggeredElement, response ) {
	document.location.href = response.data.url;
};

/**
 * Le callback en cas de réussite à la requête Ajax "redirect".
 * Redirection.
 *
 * @since   2.0.0
 * @version 2.0.0
 *
 * @param {HTMLDivElement} triggeredElement L'élement HTML déclenchant la requête Ajax.
 * @param {Object}         response         Les données renvoyées par la requête Ajax.
 */
window.eoxiaJS.wpshopFrontend.checkout.redirect = function( triggeredElement, response ) {
	document.location.href = response.data.url;
};

/**
 * Gestion JS de My account.
 *
 * @since   2.0.0
 * @version 2.0.0
 */
window.eoxiaJS.wpshopFrontend.myAccount = {};

/**
 * La méthode "init" est appelé automatiquement par la lib JS de Eo-Framework
 *
 * @since   2.0.0
 * @version 2.0.0
 */
window.eoxiaJS.wpshopFrontend.myAccount.init = function() {
	window.eoxiaJS.wpshopFrontend.myAccount.event();
};

/**
 * Les évènements de My account.
 *
 * @since   2.0.0
 * @version 2.0.0
 */
window.eoxiaJS.wpshopFrontend.myAccount.event = function() {
	jQuery( '.wps-box-display-more' ).click( function() {
		jQuery( this ).toggleClass( 'active' );
		jQuery( this ).closest( '.wps-box' ).find( '.wps-box-detail' ).slideToggle( 'fast' )
	} );
};

/**
 * Le callback en cas de réussite à la requête Ajax "reoder".
 * Redirection.
 *
 * @since   2.0.0
 * @version 2.0.0
 *
 * @param {HTMLDivElement} triggeredElement L'élement HTML déclenchant la requête Ajax.
 * @param {Object}         response         Les données renvoyées par la requête Ajax.
 */
window.eoxiaJS.wpshopFrontend.myAccount.reorderSuccess = function( triggeredElement, response ) {
	document.location.href = response.data.redirect_url;
};

/**
 * Gestion JS du produit.
 *
 * @since   2.0.0
 * @version 2.0.0
 */
window.eoxiaJS.wpshopFrontend.product = {};

/**
 * La méthode "init" est appelé automatiquement par la lib JS de Eo-Framework.
 *
 * @since 2.0.0
 * @version 2.0.0
 */
window.eoxiaJS.wpshopFrontend.product.init = function() {
	jQuery( document ).on( 'click', '.single-wps-product .wps-product .wps-quantity-minus, .single-wps-product .wps-product .wps-quantity-plus', window.eoxiaJS.wpshopFrontend.product.updateQty );
};

/**
 * Met à jour la quantité d'un produit.
 *
 * @since   2.0.0
 * @version 2.0.0
 *
 * @param {ClickEvent} event [updateQty].
 */
window.eoxiaJS.wpshopFrontend.product.updateQty = function( event ) {
	qty = parseInt( jQuery( '.single-wps-product .wps-product .wps-product-quantity .qty' ).text() );
	var price = parseFloat( jQuery( '.single-wps-product .wps-product .base-price' ).val() );
	if ( jQuery( this ).hasClass( 'wps-quantity-minus' ) ) {
		if ( qty > 1 ) {
			qty--;
		}
	}

	if ( jQuery( this ).hasClass( 'wps-quantity-plus' ) ) {
		qty++;
	}

	price *= qty;

	price = new Intl.NumberFormat( 'fr-FR', { style: 'currency', currency: 'EUR' }).format(price);

	jQuery( '.single-wps-product .wps-product' ).find( '.qty' ).text( qty );

	if ( jQuery( '.single-wps-product .wps-product .wps-product-buy' ).length > 0 ) {
		jQuery( '.single-wps-product .wps-product .wps-product-buy' ).attr( 'data-qty', qty );
	}
	jQuery( '.single-wps-product .wps-product .wps-product-price' ).text( price );
};
